import asyncio
import oprc_py
import sys

class TestHandler:
    async def invoke_fn(self, req: oprc_py.InvocationRequest) -> oprc_py.InvocationResponse:
        return oprc_py.InvocationResponse(req.payload)

    async def invoke_obj(self, req: oprc_py.ObjectInvocationRequest) -> oprc_py.InvocationResponse:
        payload = f"hello from python ({req.cls_id}, {req.fn_id}, {req.object_id})".encode("utf-8")
        # return oprc_py.InvocationResponse(payload, 0, {"key": "value"})
        return oprc_py.InvocationResponse(payload)

async def start(engine):
    engine.start_server(TestHandler())

async def test_callback():
    return "test"
    
if __name__ == "__main__":
    if sys.platform != "win32":
        import uvloop
        uvloop.install()
    else:
        import winloop
        winloop.install()
    oprc_py.init_logger()
    engine = oprc_py.OaasEngine()
    loop = asyncio.new_event_loop() 
    engine.start_server(loop, TestHandler())
    try:
        loop.run_forever()
    finally:
        engine.stop_server()
        loop.close()
    
    # asyncio.run(start(engine))


# This file is automatically generated by pyo3_stub_gen
# ruff: noqa: E501, F401

import builtins
import typing

class DataManager:
    def get_obj(self, cls_id:builtins.str, partition_id:builtins.int, obj_id:builtins.int) -> typing.Any: ...
    def set_obj(self, obj:ObjectData) -> typing.Any: ...

class InvocationRequest:
    ...

class InvocationResponse:
    def new(self, payload:typing.Sequence[builtins.int], status:builtins.int, header:typing.Mapping[builtins.str, builtins.str]) -> InvocationResponse: ...

class OaasEngine:
    data_manager: DataManager
    def __new__(cls) -> OaasEngine: ...
    def start_server(self, callback:typing.Any) -> None: ...

class ObjectData:
    ...

class ObjectInvocationRequest:
    ...

class ObjectMetadata:
    ...

